@@ -13,21 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.cloud.osconfig_v1.types import patch_deployments
-from google.cloud.osconfig_v1.types import patch_jobs
-from google.protobuf import empty_pb2  # type: ignore
-from .base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.osconfig_v1.types import patch_deployments, patch_jobs
+
+from .base import DEFAULT_CLIENT_INFO, OsConfigServiceTransport
 
 
 class OsConfigServiceGrpcTransport(OsConfigServiceTransport):
@@ -63,6 +61,7 @@ class OsConfigServiceGrpcTransport(OsConfigServiceTransport):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -158,6 +157,7 @@ class OsConfigServiceGrpcTransport(OsConfigServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -229,8 +229,7 @@ class OsConfigServiceGrpcTransport(OsConfigServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -579,5 +578,9 @@ class OsConfigServiceGrpcTransport(OsConfigServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("OsConfigServiceGrpcTransport",)
