@@ -13,21 +13,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
+from google.api_core import gapic_v1, grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
-from google.cloud.osconfig_v1.types import patch_deployments
-from google.cloud.osconfig_v1.types import patch_jobs
-from google.protobuf import empty_pb2  # type: ignore
-from .base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.osconfig_v1.types import patch_deployments, patch_jobs
+
+from .base import DEFAULT_CLIENT_INFO, OsConfigServiceTransport
 from .grpc import OsConfigServiceGrpcTransport
 
 
@@ -108,6 +106,7 @@ class OsConfigServiceGrpcAsyncIOTransport(OsConfigServiceTransport):
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -203,6 +202,7 @@ class OsConfigServiceGrpcAsyncIOTransport(OsConfigServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
