@@ -18,16 +18,18 @@ from typing import (
     AsyncIterator,
     Awaitable,
     Callable,
+    Iterator,
+    Optional,
     Sequence,
     Tuple,
-    Optional,
-    Iterator,
 )
 
-from google.cloud.osconfig_v1.types import inventory
-from google.cloud.osconfig_v1.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1.types import os_policy_assignments
-from google.cloud.osconfig_v1.types import vulnerability
+from google.cloud.osconfig_v1.types import (
+    inventory,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
 
 
 class ListOSPolicyAssignmentsPager:
@@ -344,8 +346,8 @@ class ListOSPolicyAssignmentReportsPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(
-            request
+        self._request = (
+            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(request)
         )
         self._response = response
         self._metadata = metadata
@@ -417,8 +419,8 @@ class ListOSPolicyAssignmentReportsAsyncPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(
-            request
+        self._request = (
+            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(request)
         )
         self._response = response
         self._metadata = metadata
