@@ -15,26 +15,29 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.osconfig_v1.types import inventory
-from google.cloud.osconfig_v1.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1.types import os_policy_assignments
-from google.cloud.osconfig_v1.types import vulnerability
 from google.longrunning import operations_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
+import pkg_resources
+
+from google.cloud.osconfig_v1.types import (
+    inventory,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-os-config",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-os-config",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
@@ -57,6 +60,7 @@ class OsConfigZonalServiceTransport(abc.ABC):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -83,10 +87,6 @@ class OsConfigZonalServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -108,6 +108,11 @@ class OsConfigZonalServiceTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -120,6 +125,11 @@ class OsConfigZonalServiceTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -164,10 +174,14 @@ class OsConfigZonalServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_inventory: gapic_v1.method.wrap_method(
-                self.get_inventory, default_timeout=None, client_info=client_info,
+                self.get_inventory,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_inventories: gapic_v1.method.wrap_method(
-                self.list_inventories, default_timeout=None, client_info=client_info,
+                self.list_inventories,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_vulnerability_report: gapic_v1.method.wrap_method(
                 self.get_vulnerability_report,
@@ -184,9 +198,9 @@ class OsConfigZonalServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -329,5 +343,9 @@ class OsConfigZonalServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("OsConfigZonalServiceTransport",)
