@@ -14,48 +14,55 @@
 # limitations under the License.
 #
 
-from .services.os_config_zonal_service import OsConfigZonalServiceClient
-from .services.os_config_zonal_service import OsConfigZonalServiceAsyncClient
-
-from .types.config_common import OSPolicyResourceCompliance
-from .types.config_common import OSPolicyResourceConfigStep
-from .types.config_common import OSPolicyComplianceState
+from .services.os_config_zonal_service import (
+    OsConfigZonalServiceAsyncClient,
+    OsConfigZonalServiceClient,
+)
+from .types.config_common import (
+    OSPolicyComplianceState,
+    OSPolicyResourceCompliance,
+    OSPolicyResourceConfigStep,
+)
 from .types.instance_os_policies_compliance import (
     GetInstanceOSPoliciesComplianceRequest,
-)
-from .types.instance_os_policies_compliance import InstanceOSPoliciesCompliance
-from .types.instance_os_policies_compliance import (
+    InstanceOSPoliciesCompliance,
     ListInstanceOSPoliciesCompliancesRequest,
-)
-from .types.instance_os_policies_compliance import (
     ListInstanceOSPoliciesCompliancesResponse,
 )
-from .types.inventory import GetInventoryRequest
-from .types.inventory import Inventory
-from .types.inventory import ListInventoriesRequest
-from .types.inventory import ListInventoriesResponse
-from .types.inventory import InventoryView
+from .types.inventory import (
+    GetInventoryRequest,
+    Inventory,
+    InventoryView,
+    ListInventoriesRequest,
+    ListInventoriesResponse,
+)
 from .types.os_policy import OSPolicy
-from .types.os_policy_assignment_reports import GetOSPolicyAssignmentReportRequest
-from .types.os_policy_assignment_reports import ListOSPolicyAssignmentReportsRequest
-from .types.os_policy_assignment_reports import ListOSPolicyAssignmentReportsResponse
-from .types.os_policy_assignment_reports import OSPolicyAssignmentReport
-from .types.os_policy_assignments import CreateOSPolicyAssignmentRequest
-from .types.os_policy_assignments import DeleteOSPolicyAssignmentRequest
-from .types.os_policy_assignments import GetOSPolicyAssignmentRequest
-from .types.os_policy_assignments import ListOSPolicyAssignmentRevisionsRequest
-from .types.os_policy_assignments import ListOSPolicyAssignmentRevisionsResponse
-from .types.os_policy_assignments import ListOSPolicyAssignmentsRequest
-from .types.os_policy_assignments import ListOSPolicyAssignmentsResponse
-from .types.os_policy_assignments import OSPolicyAssignment
-from .types.os_policy_assignments import OSPolicyAssignmentOperationMetadata
-from .types.os_policy_assignments import UpdateOSPolicyAssignmentRequest
+from .types.os_policy_assignment_reports import (
+    GetOSPolicyAssignmentReportRequest,
+    ListOSPolicyAssignmentReportsRequest,
+    ListOSPolicyAssignmentReportsResponse,
+    OSPolicyAssignmentReport,
+)
+from .types.os_policy_assignments import (
+    CreateOSPolicyAssignmentRequest,
+    DeleteOSPolicyAssignmentRequest,
+    GetOSPolicyAssignmentRequest,
+    ListOSPolicyAssignmentRevisionsRequest,
+    ListOSPolicyAssignmentRevisionsResponse,
+    ListOSPolicyAssignmentsRequest,
+    ListOSPolicyAssignmentsResponse,
+    OSPolicyAssignment,
+    OSPolicyAssignmentOperationMetadata,
+    UpdateOSPolicyAssignmentRequest,
+)
 from .types.osconfig_common import FixedOrPercent
-from .types.vulnerability import CVSSv3
-from .types.vulnerability import GetVulnerabilityReportRequest
-from .types.vulnerability import ListVulnerabilityReportsRequest
-from .types.vulnerability import ListVulnerabilityReportsResponse
-from .types.vulnerability import VulnerabilityReport
+from .types.vulnerability import (
+    CVSSv3,
+    GetVulnerabilityReportRequest,
+    ListVulnerabilityReportsRequest,
+    ListVulnerabilityReportsResponse,
+    VulnerabilityReport,
+)
 
 __all__ = (
     "OsConfigZonalServiceAsyncClient",
