@@ -13,25 +13,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import grpc_helpers
-from google.api_core import operations_v1
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, grpc_helpers, operations_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
 import grpc  # type: ignore
 
-from google.cloud.osconfig_v1alpha.types import instance_os_policies_compliance
-from google.cloud.osconfig_v1alpha.types import inventory
-from google.cloud.osconfig_v1alpha.types import os_policy_assignment_reports
-from google.cloud.osconfig_v1alpha.types import os_policy_assignments
-from google.cloud.osconfig_v1alpha.types import vulnerability
-from google.longrunning import operations_pb2  # type: ignore
-from .base import OsConfigZonalServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.osconfig_v1alpha.types import (
+    instance_os_policies_compliance,
+    inventory,
+    os_policy_assignment_reports,
+    os_policy_assignments,
+    vulnerability,
+)
+
+from .base import DEFAULT_CLIENT_INFO, OsConfigZonalServiceTransport
 
 
 class OsConfigZonalServiceGrpcTransport(OsConfigZonalServiceTransport):
@@ -67,6 +67,7 @@ class OsConfigZonalServiceGrpcTransport(OsConfigZonalServiceTransport):
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -163,6 +164,7 @@ class OsConfigZonalServiceGrpcTransport(OsConfigZonalServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -234,8 +236,7 @@ class OsConfigZonalServiceGrpcTransport(OsConfigZonalServiceTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -719,5 +720,9 @@ class OsConfigZonalServiceGrpcTransport(OsConfigZonalServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("OsConfigZonalServiceGrpcTransport",)
