@@ -13,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.osconfig.v1alpha",
@@ -124,14 +122,36 @@ class VulnerabilityReport(proto.Message):
                         The source of the reference e.g. NVD.
                 """
 
-                url = proto.Field(proto.STRING, number=1,)
-                source = proto.Field(proto.STRING, number=2,)
+                url = proto.Field(
+                    proto.STRING,
+                    number=1,
+                )
+                source = proto.Field(
+                    proto.STRING,
+                    number=2,
+                )
 
-            cve = proto.Field(proto.STRING, number=1,)
-            cvss_v2_score = proto.Field(proto.FLOAT, number=2,)
-            cvss_v3 = proto.Field(proto.MESSAGE, number=3, message="CVSSv3",)
-            severity = proto.Field(proto.STRING, number=4,)
-            description = proto.Field(proto.STRING, number=5,)
+            cve = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            cvss_v2_score = proto.Field(
+                proto.FLOAT,
+                number=2,
+            )
+            cvss_v3 = proto.Field(
+                proto.MESSAGE,
+                number=3,
+                message="CVSSv3",
+            )
+            severity = proto.Field(
+                proto.STRING,
+                number=4,
+            )
+            description = proto.Field(
+                proto.STRING,
+                number=5,
+            )
             references = proto.RepeatedField(
                 proto.MESSAGE,
                 number=6,
@@ -167,33 +187,66 @@ class VulnerabilityReport(proto.Message):
                     fixes the vulnerability.
             """
 
-            installed_inventory_item_id = proto.Field(proto.STRING, number=1,)
-            available_inventory_item_id = proto.Field(proto.STRING, number=2,)
-            fixed_cpe_uri = proto.Field(proto.STRING, number=3,)
-            upstream_fix = proto.Field(proto.STRING, number=4,)
+            installed_inventory_item_id = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            available_inventory_item_id = proto.Field(
+                proto.STRING,
+                number=2,
+            )
+            fixed_cpe_uri = proto.Field(
+                proto.STRING,
+                number=3,
+            )
+            upstream_fix = proto.Field(
+                proto.STRING,
+                number=4,
+            )
 
         details = proto.Field(
             proto.MESSAGE,
             number=1,
             message="VulnerabilityReport.Vulnerability.Details",
         )
-        installed_inventory_item_ids = proto.RepeatedField(proto.STRING, number=2,)
-        available_inventory_item_ids = proto.RepeatedField(proto.STRING, number=3,)
+        installed_inventory_item_ids = proto.RepeatedField(
+            proto.STRING,
+            number=2,
+        )
+        available_inventory_item_ids = proto.RepeatedField(
+            proto.STRING,
+            number=3,
+        )
         create_time = proto.Field(
-            proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=4,
+            message=timestamp_pb2.Timestamp,
         )
         update_time = proto.Field(
-            proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
+            proto.MESSAGE,
+            number=5,
+            message=timestamp_pb2.Timestamp,
         )
         items = proto.RepeatedField(
-            proto.MESSAGE, number=6, message="VulnerabilityReport.Vulnerability.Item",
+            proto.MESSAGE,
+            number=6,
+            message="VulnerabilityReport.Vulnerability.Item",
         )
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     vulnerabilities = proto.RepeatedField(
-        proto.MESSAGE, number=2, message=Vulnerability,
+        proto.MESSAGE,
+        number=2,
+        message=Vulnerability,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
 
 
 class GetVulnerabilityReportRequest(proto.Message):
@@ -213,7 +266,10 @@ class GetVulnerabilityReportRequest(proto.Message):
             provided.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListVulnerabilityReportsRequest(proto.Message):
@@ -241,10 +297,22 @@ class ListVulnerabilityReportsRequest(proto.Message):
             in the response.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListVulnerabilityReportsResponse(proto.Message):
@@ -264,9 +332,14 @@ class ListVulnerabilityReportsResponse(proto.Message):
         return self
 
     vulnerability_reports = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="VulnerabilityReport",
+        proto.MESSAGE,
+        number=1,
+        message="VulnerabilityReport",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CVSSv3(proto.Message):
@@ -377,17 +450,58 @@ class CVSSv3(proto.Message):
         IMPACT_LOW = 2
         IMPACT_NONE = 3
 
-    base_score = proto.Field(proto.FLOAT, number=1,)
-    exploitability_score = proto.Field(proto.FLOAT, number=2,)
-    impact_score = proto.Field(proto.FLOAT, number=3,)
-    attack_vector = proto.Field(proto.ENUM, number=5, enum=AttackVector,)
-    attack_complexity = proto.Field(proto.ENUM, number=6, enum=AttackComplexity,)
-    privileges_required = proto.Field(proto.ENUM, number=7, enum=PrivilegesRequired,)
-    user_interaction = proto.Field(proto.ENUM, number=8, enum=UserInteraction,)
-    scope = proto.Field(proto.ENUM, number=9, enum=Scope,)
-    confidentiality_impact = proto.Field(proto.ENUM, number=10, enum=Impact,)
-    integrity_impact = proto.Field(proto.ENUM, number=11, enum=Impact,)
-    availability_impact = proto.Field(proto.ENUM, number=12, enum=Impact,)
+    base_score = proto.Field(
+        proto.FLOAT,
+        number=1,
+    )
+    exploitability_score = proto.Field(
+        proto.FLOAT,
+        number=2,
+    )
+    impact_score = proto.Field(
+        proto.FLOAT,
+        number=3,
+    )
+    attack_vector = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=AttackVector,
+    )
+    attack_complexity = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=AttackComplexity,
+    )
+    privileges_required = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum=PrivilegesRequired,
+    )
+    user_interaction = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=UserInteraction,
+    )
+    scope = proto.Field(
+        proto.ENUM,
+        number=9,
+        enum=Scope,
+    )
+    confidentiality_impact = proto.Field(
+        proto.ENUM,
+        number=10,
+        enum=Impact,
+    )
+    integrity_impact = proto.Field(
+        proto.ENUM,
+        number=11,
+        enum=Impact,
+    )
+    availability_impact = proto.Field(
+        proto.ENUM,
+        number=12,
+        enum=Impact,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
